**Example 1: 添加用户组成员**

添加用户组成员

Input: 

```
tccli dasb AddUserGroupMembers --cli-unfold-argument  \
    --Id 1 \
    --MemberIdSet 1 2 3
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

